@@ -10,13 +10,12 @@ from sql.conditionals import Coalesce
 from trytond import backend
 from trytond.i18n import gettext
 from trytond.model import (
-    DeactivableMixin, ModelSQL, ModelView, Unique, fields, tree)
+    DeactivableMixin, Index, ModelSQL, ModelView, Unique, fields, tree)
 from trytond.modules.currency.fields import Monetary
 from trytond.pool import Pool
 from trytond.pyson import Eval, If, PYSONDecoder, PYSONEncoder
-from trytond.tools import lstrip_wildcard
+from trytond.tools import is_full_text, lstrip_wildcard
 from trytond.transaction import Transaction
-from trytond.wizard import Button, StateAction, StateView, Wizard
 
 from .exceptions import AccountValidationError
 
@@ -26,8 +25,8 @@ class Account(
         ModelSQL, ModelView):
     'Analytic Account'
     __name__ = 'analytic_account.account'
-    name = fields.Char('Name', required=True, translate=True, select=True)
-    code = fields.Char('Code', select=True)
+    name = fields.Char("Name", required=True, translate=True)
+    code = fields.Char("Code")
     company = fields.Many2One('company.company', 'Company', required=True)
     currency = fields.Function(
         fields.Many2One('currency.currency', 'Currency'),
@@ -38,7 +37,8 @@ class Account(
         ('normal', 'Normal'),
         ('distribution', 'Distribution'),
         ], 'Type', required=True)
-    root = fields.Many2One('analytic_account.account', 'Root', select=True,
+    root = fields.Many2One(
+        'analytic_account.account', "Root",
         domain=[
             ('company', '=', Eval('company', -1)),
             ('parent', '=', None),
@@ -48,7 +48,8 @@ class Account(
             'invisible': Eval('type') == 'root',
             'required': Eval('type') != 'root',
             })
-    parent = fields.Many2One('analytic_account.account', 'Parent', select=True,
+    parent = fields.Many2One(
+        'analytic_account.account', "Parent",
         domain=['OR',
             ('root', '=', Eval('root', -1)),
             ('parent', '=', None),
@@ -92,7 +93,11 @@ class Account(
 
     @classmethod
     def __setup__(cls):
+        cls.code.search_unaccented = False
         super(Account, cls).__setup__()
+        t = cls.__table__()
+        cls._sql_indexes.add(
+            Index(t, (t.code, Index.Similarity())))
         cls._order.insert(0, ('code', 'ASC'))
         cls._order.insert(1, ('name', 'ASC'))
 
@@ -259,16 +264,17 @@ class Account(
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        if clause[1].startswith('!') or clause[1].startswith('not '):
+        _, operator, operand, *extra = clause
+        if operator.startswith('!') or operator.startswith('not '):
             bool_op = 'AND'
         else:
             bool_op = 'OR'
-        code_value = clause[2]
-        if clause[1].endswith('like'):
-            code_value = lstrip_wildcard(clause[2])
+        code_value = operand
+        if operator.endswith('like') and is_full_text(operand):
+            code_value = lstrip_wildcard(operand)
         return [bool_op,
-            ('code', clause[1], code_value) + tuple(clause[3:]),
-            (cls._rec_name,) + tuple(clause[1:]),
+            ('code', operator, code_value, *extra),
+            (cls._rec_name, operator, operand, *extra),
             ]
 
     def distribute(self, amount):
@@ -297,39 +303,18 @@ class Account(
             return result
 
 
-class OpenChartAccountStart(ModelView):
+class AccountContext(ModelView):
     'Open Chart of Accounts'
-    __name__ = 'analytic_account.open_chart.start'
+    __name__ = 'analytic_account.account.context'
     start_date = fields.Date('Start Date')
     end_date = fields.Date('End Date')
 
 
-class OpenChartAccount(Wizard):
-    'Open Chart of Accounts'
-    __name__ = 'analytic_account.open_chart'
-    start = StateView('analytic_account.open_chart.start',
-        'analytic_account.open_chart_start_view_form', [
-            Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Open', 'open_', 'tryton-ok', default=True),
-            ])
-    open_ = StateAction('analytic_account.act_account_tree2')
-
-    def do_open_(self, action):
-        action['pyson_context'] = PYSONEncoder().encode({
-                'start_date': self.start.start_date,
-                'end_date': self.start.end_date,
-                })
-        return action, {}
-
-    def transition_open_(self):
-        return 'end'
-
-
 class AccountDistribution(ModelView, ModelSQL):
     "Analytic Account Distribution"
     __name__ = 'analytic_account.account.distribution'
     parent = fields.Many2One(
-        'analytic_account.account', "Parent", required=True, select=True)
+        'analytic_account.account', "Parent", required=True)
     root = fields.Function(
         fields.Many2One('analytic_account.account', "Root"),
         'on_change_with_root')
@@ -358,7 +343,7 @@ class AccountDistribution(ModelView, ModelSQL):
 class AnalyticAccountEntry(ModelView, ModelSQL):
     'Analytic Account Entry'
     __name__ = 'analytic.account.entry'
-    origin = fields.Reference('Origin', selection='get_origin', select=True)
+    origin = fields.Reference('Origin', selection='get_origin')
     root = fields.Many2One(
         'analytic_account.account', "Root Analytic", required=True,
         domain=[
@@ -419,6 +404,7 @@ class AnalyticAccountEntry(ModelView, ModelSQL):
             ('root_origin_uniq', Unique(t, t.origin, t.root),
                 'analytic_account.msg_root_origin_unique'),
             ]
+        cls._sql_indexes.add(Index(t, (t.origin, Index.Equality())))
 
     @classmethod
     def _get_origin(cls):
